@@ -188,16 +188,16 @@ class UserPoolWithMfa(
         :param mfa_second_factor: Configure the MFA types that users can use in this user pool. Ignored if ``mfa`` is set to ``OFF``. Default: - { sms: true, otp: false }, if ``mfa`` is set to ``OPTIONAL`` or ``REQUIRED``. { sms: false, otp: false }, otherwise
         :param password_policy: Password policy for this user pool. Default: - see defaults on each property of PasswordPolicy.
         :param removal_policy: Policy to apply when the user pool is removed from the stack. Default: RemovalPolicy.RETAIN
-        :param self_sign_up_enabled: Whether self sign up should be enabled. This can be further configured via the ``selfSignUp`` property. Default: false
+        :param self_sign_up_enabled: Whether self sign-up should be enabled. To configure self sign-up configuration use the ``userVerification`` property. Default: - false
         :param sign_in_aliases: Methods in which a user registers or signs in to a user pool. Allows either username with aliases OR sign in with email, phone, or both. Read the sections on usernames and aliases to learn more - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html To match with 'Option 1' in the above link, with a verified email, this property should be set to ``{ username: true, email: true }``. To match with 'Option 2' in the above link with both a verified email and phone number, this property should be set to ``{ email: true, phone: true }``. Default: { username: true }
         :param sign_in_case_sensitive: Whether sign-in aliases should be evaluated with case sensitivity. For example, when this option is set to false, users will be able to sign in using either ``MyUsername`` or ``myusername``. Default: true
-        :param sms_role: The IAM role that Cognito will assume while sending SMS messages. Default: - a new IAM role is created
-        :param sms_role_external_id: The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional. Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html This property will be ignored if ``smsRole`` is not specified. Default: - No external id will be configured
-        :param sns_region: The region to integrate with SNS to send SMS messages. This property will do nothing if SMS configuration is not configured Default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
+        :param sms_role: The IAM role that Cognito will assume while sending SMS messages. Default: - a new IAM role is created.
+        :param sms_role_external_id: The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional. Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html This property will be ignored if ``smsRole`` is not specified. Default: - No external id will be configured.
+        :param sns_region: The region to integrate with SNS to send SMS messages. This property will do nothing if SMS configuration is not configured. Default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
         :param standard_attributes: The set of attributes that are required for every user in the user pool. Read more on attributes here - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html Default: - All standard attributes are optional and mutable.
-        :param user_invitation: Configuration around admins signing up users into a user pool. Default: - see defaults in UserInvitationConfig
-        :param user_pool_name: Name of the user pool. Default: - automatically generated name by CloudFormation at deploy time
-        :param user_verification: Configuration around users signing themselves up to the user pool. Enable or disable self sign-up via the ``selfSignUpEnabled`` property. Default: - see defaults in UserVerificationConfig
+        :param user_invitation: Configuration around admins signing up users into a user pool. Default: - see defaults in UserInvitationConfig.
+        :param user_pool_name: Name of the user pool. Default: - automatically generated name by CloudFormation at deploy time.
+        :param user_verification: Configuration around users signing themselves up to the user pool. Enable or disable self sign-up via the ``selfSignUpEnabled`` property. Default: - see defaults in UserVerificationConfig.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__fa66be073edba83d19edc44f0da937d528deb57625d13c7719a5f653bf5482b8)
@@ -316,16 +316,16 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
         :param mfa_second_factor: Configure the MFA types that users can use in this user pool. Ignored if ``mfa`` is set to ``OFF``. Default: - { sms: true, otp: false }, if ``mfa`` is set to ``OPTIONAL`` or ``REQUIRED``. { sms: false, otp: false }, otherwise
         :param password_policy: Password policy for this user pool. Default: - see defaults on each property of PasswordPolicy.
         :param removal_policy: Policy to apply when the user pool is removed from the stack. Default: RemovalPolicy.RETAIN
-        :param self_sign_up_enabled: Whether self sign up should be enabled. This can be further configured via the ``selfSignUp`` property. Default: false
+        :param self_sign_up_enabled: Whether self sign-up should be enabled. To configure self sign-up configuration use the ``userVerification`` property. Default: - false
         :param sign_in_aliases: Methods in which a user registers or signs in to a user pool. Allows either username with aliases OR sign in with email, phone, or both. Read the sections on usernames and aliases to learn more - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html To match with 'Option 1' in the above link, with a verified email, this property should be set to ``{ username: true, email: true }``. To match with 'Option 2' in the above link with both a verified email and phone number, this property should be set to ``{ email: true, phone: true }``. Default: { username: true }
         :param sign_in_case_sensitive: Whether sign-in aliases should be evaluated with case sensitivity. For example, when this option is set to false, users will be able to sign in using either ``MyUsername`` or ``myusername``. Default: true
-        :param sms_role: The IAM role that Cognito will assume while sending SMS messages. Default: - a new IAM role is created
-        :param sms_role_external_id: The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional. Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html This property will be ignored if ``smsRole`` is not specified. Default: - No external id will be configured
-        :param sns_region: The region to integrate with SNS to send SMS messages. This property will do nothing if SMS configuration is not configured Default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
+        :param sms_role: The IAM role that Cognito will assume while sending SMS messages. Default: - a new IAM role is created.
+        :param sms_role_external_id: The 'ExternalId' that Cognito service must be using when assuming the ``smsRole``, if the role is restricted with an 'sts:ExternalId' conditional. Learn more about ExternalId here - https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html This property will be ignored if ``smsRole`` is not specified. Default: - No external id will be configured.
+        :param sns_region: The region to integrate with SNS to send SMS messages. This property will do nothing if SMS configuration is not configured. Default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
         :param standard_attributes: The set of attributes that are required for every user in the user pool. Read more on attributes here - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-attributes.html Default: - All standard attributes are optional and mutable.
-        :param user_invitation: Configuration around admins signing up users into a user pool. Default: - see defaults in UserInvitationConfig
-        :param user_pool_name: Name of the user pool. Default: - automatically generated name by CloudFormation at deploy time
-        :param user_verification: Configuration around users signing themselves up to the user pool. Enable or disable self sign-up via the ``selfSignUpEnabled`` property. Default: - see defaults in UserVerificationConfig
+        :param user_invitation: Configuration around admins signing up users into a user pool. Default: - see defaults in UserInvitationConfig.
+        :param user_pool_name: Name of the user pool. Default: - automatically generated name by CloudFormation at deploy time.
+        :param user_verification: Configuration around users signing themselves up to the user pool. Enable or disable self sign-up via the ``selfSignUpEnabled`` property. Default: - see defaults in UserVerificationConfig.
         '''
         if isinstance(auto_verify, dict):
             auto_verify = _aws_cdk_aws_cognito_ceddda9d.AutoVerifiedAttrs(**auto_verify)
@@ -613,11 +613,11 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
 
     @builtins.property
     def self_sign_up_enabled(self) -> typing.Optional[builtins.bool]:
-        '''Whether self sign up should be enabled.
+        '''Whether self sign-up should be enabled.
 
-        This can be further configured via the ``selfSignUp`` property.
+        To configure self sign-up configuration use the ``userVerification`` property.
 
-        :default: false
+        :default: - false
         '''
         result = self._values.get("self_sign_up_enabled")
         return typing.cast(typing.Optional[builtins.bool], result)
@@ -657,7 +657,7 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
     def sms_role(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''The IAM role that Cognito will assume while sending SMS messages.
 
-        :default: - a new IAM role is created
+        :default: - a new IAM role is created.
         '''
         result = self._values.get("sms_role")
         return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
@@ -670,7 +670,7 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
 
         This property will be ignored if ``smsRole`` is not specified.
 
-        :default: - No external id will be configured
+        :default: - No external id will be configured.
         '''
         result = self._values.get("sms_role_external_id")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -679,7 +679,7 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
     def sns_region(self) -> typing.Optional[builtins.str]:
         '''The region to integrate with SNS to send SMS messages.
 
-        This property will do nothing if SMS configuration is not configured
+        This property will do nothing if SMS configuration is not configured.
 
         :default: - The same region as the user pool, with a few exceptions - https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html#user-pool-sms-settings-first-time
         '''
@@ -705,7 +705,7 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
     ) -> typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig]:
         '''Configuration around admins signing up users into a user pool.
 
-        :default: - see defaults in UserInvitationConfig
+        :default: - see defaults in UserInvitationConfig.
         '''
         result = self._values.get("user_invitation")
         return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserInvitationConfig], result)
@@ -714,7 +714,7 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
     def user_pool_name(self) -> typing.Optional[builtins.str]:
         '''Name of the user pool.
 
-        :default: - automatically generated name by CloudFormation at deploy time
+        :default: - automatically generated name by CloudFormation at deploy time.
         '''
         result = self._values.get("user_pool_name")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -727,7 +727,7 @@ class UserPoolWithMfaProps(_aws_cdk_aws_cognito_ceddda9d.UserPoolProps):
 
         Enable or disable self sign-up via the ``selfSignUpEnabled`` property.
 
-        :default: - see defaults in UserVerificationConfig
+        :default: - see defaults in UserVerificationConfig.
         '''
         result = self._values.get("user_verification")
         return typing.cast(typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserVerificationConfig], result)
